buddy.auth.backends


api-keyclj

Alias for apikey.

Alias for `apikey`.
sourceraw docstring

apikeyclj

(apikey)
(apikey opts)

Create an API-key authentication backend.

Create an API-key authentication backend.
sourceraw docstring

basicclj

(basic)
(basic opts)

Create an HTTP Basic authentication backend.

This backend also implements an authorization workflow with default behavior. Provide an unauthorized-handler hook to change the default behavior.

Create an HTTP Basic authentication backend.

This backend also implements an authorization workflow with default behavior.
Provide an unauthorized-handler hook to change the default behavior.
sourceraw docstring

discover-jwks-urlclj

(discover-jwks-url issuer)
(discover-jwks-url issuer fetch-json)

Discover an OIDC provider's JWKS URL.

Requires the optional net.clojars.savya/jose-clj dependency.

Discover an OIDC provider's JWKS URL.

Requires the optional `net.clojars.savya/jose-clj` dependency.
sourceraw docstring

http-basicclj

Alias for basic.

Alias for `basic`.
sourceraw docstring

jweclj

(jwe)
(jwe opts)

Create a JWE encrypted JWT authentication backend.

This backend also implements an authorization workflow with default behavior. Provide an unauthorized-handler hook to change the default behavior.

Create a JWE encrypted JWT authentication backend.

This backend also implements an authorization workflow with default behavior.
Provide an unauthorized-handler hook to change the default behavior.
sourceraw docstring

jwksclj

(jwks opts)

Create a JWKS authentication backend.

This backend validates bearer tokens against a JWK Set or JWKS endpoint. It supports claim validation with the :options map.

This backend requires the optional net.clojars.savya/jose-clj dependency on the classpath. Add it to your project to use this backend. Otherwise, it throws an exception.

This backend also implements an authorization workflow with default behavior. Provide an unauthorized-handler hook to change the default behavior.

Create a JWKS authentication backend.

This backend validates bearer tokens against a JWK Set
or JWKS endpoint. It supports claim validation with the :options map.

This backend requires the optional `net.clojars.savya/jose-clj` dependency
on the classpath. Add it to your project to use this backend. Otherwise, it
throws an exception.

This backend also implements an authorization workflow with default behavior.
Provide an unauthorized-handler hook to change the default behavior.
sourceraw docstring

jwsclj

(jws)
(jws opts)

Create a JWS signed JWT authentication backend.

This backend also implements an authorization workflow with default behavior. Provide an unauthorized-handler hook to change the default behavior.

Create a JWS signed JWT authentication backend.

This backend also implements an authorization workflow with default behavior.
Provide an unauthorized-handler hook to change the default behavior.
sourceraw docstring

oidcclj

(oidc opts)

Create a JWKS authentication backend using OIDC issuer discovery.

Requires the optional net.clojars.savya/jose-clj dependency.

Create a JWKS authentication backend using OIDC issuer discovery.

Requires the optional `net.clojars.savya/jose-clj` dependency.
sourceraw docstring

sessionclj

(session)
(session opts)

Create an HTTP session authentication backend.

This backend also implements an authorization workflow with default behavior. Provide an unauthorized-handler hook to change the default behavior.

Create an HTTP session authentication backend.

This backend also implements an authorization workflow with default behavior.
Provide an unauthorized-handler hook to change the default behavior.
sourceraw docstring

tokenclj

(token)
(token opts)

Create a generic token authentication backend.

This backend also implements an authorization workflow with default behavior. Provide an unauthorized-handler hook to change the default behavior.

Create a generic token authentication backend.

This backend also implements an authorization workflow with default behavior.
Provide an unauthorized-handler hook to change the default behavior.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries