buddy.auth.backends.apikey

API-key authentication and authorization backend.

API-key authentication and authorization backend.
raw docstring

api-key-backendclj

(api-key-backend &
                 [{:keys [authfn unauthorized-handler location header-name
                          cookie-name query-param]
                   :or {location :header
                        header-name "X-API-Key"
                        cookie-name "api-key"
                        query-param "api-key"}}])
source

parse-keyclj

(parse-key request location header-name cookie-name query-param)

Extract an API key from a Ring request according to its location.

Extract an API key from a Ring request according to its location.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries