buddy.auth.http

The HTTP request and response abstraction for built-in authentication and authorization backends.

The HTTP request and response abstraction for built-in authentication and
authorization backends.
raw docstring

find-headerclj

(find-header headers header-name)

Look up a header in a headers map without case sensitivity. Return the header map entry or nil.

Look up a header in a headers map without case sensitivity.
Return the header map entry or nil.
sourceraw docstring

IRequestcljprotocol

-get-headerclj

(-get-header req name)

Get a value of header.

Get a value of header.
source

redirectclj

(redirect url)
(redirect url status)

Returns a Ring compatible response for an HTTP 302 redirect.

Returns a Ring compatible response for an HTTP 302 redirect.
sourceraw docstring

responseclj

(response body)
(response body status)
(response body status headers)

Create a Ring-compatible response with multiple arities.

Create a Ring-compatible response with multiple arities.
sourceraw docstring

response?clj

(response? resp)
source

cljdoc builds & hosts documentation for Clojure/Script libraries