buddy.auth.middleware


authenticate-requestclj

(authenticate-request request backends)

Run the authentication backend chain for a request. Return the identity of the first backend that authenticates the request.

This public function is for internal use. It helps in environments other than Ring.

Run the authentication backend chain for a request. Return the identity of
the first backend that authenticates the request.

This public function is for internal use. It helps in environments other than Ring.
sourceraw docstring

authentication-requestclj

(authentication-request request & backends)

Update a request with authentication. If multiple backends are given, each backend can authenticate the request.

This public function is for internal use. It helps in environments other than Ring.

Update a request with authentication. If multiple `backends` are given,
each backend can authenticate the request.

This public function is for internal use. It helps in environments other than Ring.
sourceraw docstring

authorization-errorclj

(authorization-error request e backend)

Handle authorization errors.

The backend parameter must be a function that accepts a request and errordata hash map, or an instance that satisfies the IAuthorization protocol.

Handle authorization errors.

The `backend` parameter must be a function that accepts a request and errordata
hash map, or an instance that satisfies the IAuthorization protocol.
sourceraw docstring

wrap-authenticationclj

(wrap-authentication handler & backends)

Ring middleware that enables authentication for a Ring handler. If multiple backends are given, each backend can authenticate the request.

Ring middleware that enables authentication for a Ring handler. If multiple
`backends` are given, each backend can authenticate the request.
sourceraw docstring

wrap-authorizationclj

(wrap-authorization handler backend)

Ring middleware that enables an authorization workflow for a Ring handler.

The backend parameter must be a function that accepts a request and errordata hash map, or an instance that satisfies the IAuthorization protocol.

Ring middleware that enables an authorization workflow for a Ring handler.

The `backend` parameter must be a function that accepts a request and errordata
hash map, or an instance that satisfies the IAuthorization protocol.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries