buddy.auth.protocols

Main authentication and authorization abstractions defined as protocols.

Main authentication and authorization abstractions defined as protocols.
raw docstring

IAuthenticationcljprotocol

Protocol that defines workflow steps for all authentication backends.

Protocol that defines workflow steps for all authentication backends.

-authenticateclj

(-authenticate _ request data)

Given a request and parsed data from the previous step, authenticate the data.

If this method returns a non-nil value, the request is authenticated. The value is attached to the request under the :identity attribute.

Given a request and parsed data from the previous step, authenticate the data.

If this method returns a non-nil value, the request is authenticated. The
value is attached to the request under the `:identity` attribute.

-parseclj

(-parse _ request)

Parse a token from the request. If it returns nil, the authenticate phase is skipped and the handler is called directly.

Parse a token from the request. If it returns `nil`, the `authenticate`
phase is skipped and the handler is called directly.
sourceraw docstring

IAuthorizationcljprotocol

Protocol that defines workflow steps for authorization exceptions.

Protocol that defines workflow steps for authorization exceptions.

-handle-unauthorizedclj

(-handle-unauthorized _ request metadata)

This function runs when an authorization wrapper intercepts a NotAuthorizedException.

It should return a valid ring response.

This function runs when an authorization wrapper intercepts a
`NotAuthorizedException`.

It should return a valid ring response.
sourceraw docstring

IAuthorizationdErrorcljprotocol

Abstraction that lets a user extend the exception-based authorization system with user-defined types.

Abstraction that lets a user extend the exception-based authorization system
with user-defined types.

-get-error-dataclj

(-get-error-data _)

Get error information.

Get error information.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries