(basic)(basic opts)Create an HTTP Basic authentication backend.
This backend also implements an authorization workflow with default behavior. Provide an unauthorized-handler hook to change the default behavior.
Create an HTTP Basic authentication backend. This backend also implements an authorization workflow with default behavior. Provide an unauthorized-handler hook to change the default behavior.
(jwe)(jwe opts)Create a JWE encrypted JWT authentication backend.
This backend also implements an authorization workflow with default behavior. Provide an unauthorized-handler hook to change the default behavior.
Create a JWE encrypted JWT authentication backend. This backend also implements an authorization workflow with default behavior. Provide an unauthorized-handler hook to change the default behavior.
(jwks opts)Create a JWKS authentication backend.
This backend validates bearer tokens against a JWK Set or JWKS endpoint. It supports claim validation with the :options map.
This backend requires the optional net.clojars.savya/jose-clj dependency
on the classpath. Add it to your project to use this backend. Otherwise, it
throws an exception.
This backend also implements an authorization workflow with default behavior. Provide an unauthorized-handler hook to change the default behavior.
Create a JWKS authentication backend. This backend validates bearer tokens against a JWK Set or JWKS endpoint. It supports claim validation with the :options map. This backend requires the optional `net.clojars.savya/jose-clj` dependency on the classpath. Add it to your project to use this backend. Otherwise, it throws an exception. This backend also implements an authorization workflow with default behavior. Provide an unauthorized-handler hook to change the default behavior.
(jws)(jws opts)Create a JWS signed JWT authentication backend.
This backend also implements an authorization workflow with default behavior. Provide an unauthorized-handler hook to change the default behavior.
Create a JWS signed JWT authentication backend. This backend also implements an authorization workflow with default behavior. Provide an unauthorized-handler hook to change the default behavior.
(session)(session opts)Create an HTTP session authentication backend.
This backend also implements an authorization workflow with default behavior. Provide an unauthorized-handler hook to change the default behavior.
Create an HTTP session authentication backend. This backend also implements an authorization workflow with default behavior. Provide an unauthorized-handler hook to change the default behavior.
(token)(token opts)Create a generic token authentication backend.
This backend also implements an authorization workflow with default behavior. Provide an unauthorized-handler hook to change the default behavior.
Create a generic token authentication backend. This backend also implements an authorization workflow with default behavior. Provide an unauthorized-handler hook to change the default behavior.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |