(basic)(basic opts)Create an instance of the http-basic based authentication backend.
This backend also implements authorization workflow with some defaults. This means that you can provide your own unauthorized-handler hook if the default one does not satisfy you.
Create an instance of the http-basic based authentication backend. This backend also implements authorization workflow with some defaults. This means that you can provide your own unauthorized-handler hook if the default one does not satisfy you.
(jwe)(jwe opts)Create an instance of the jwe (encrypted JWT based authentication backend.
This backend also implements authorization workflow with some defaults. This means that you can provide your own unauthorized-handler hook if the default one does not satisfy you.
Create an instance of the jwe (encrypted JWT based authentication backend. This backend also implements authorization workflow with some defaults. This means that you can provide your own unauthorized-handler hook if the default one does not satisfy you.
(jwks opts)Create an instance of the JWKS based authentication backend.
This backend validates bearer tokens against a JWK Set or JWKS endpoint and supports full claim validation via the :options map.
Requires the optional net.clojars.savya/jose-clj
dependency on the classpath; add it to your project to
use this backend. A clear exception is thrown otherwise.
This backend also implements authorization workflow with some defaults. This means that you can provide your own unauthorized-handler hook if the default one does not satisfy you.
Create an instance of the JWKS based authentication backend. This backend validates bearer tokens against a JWK Set or JWKS endpoint and supports full claim validation via the :options map. Requires the optional `net.clojars.savya/jose-clj` dependency on the classpath; add it to your project to use this backend. A clear exception is thrown otherwise. This backend also implements authorization workflow with some defaults. This means that you can provide your own unauthorized-handler hook if the default one does not satisfy you.
(jws)(jws opts)Create an instance of the jws (signed JWT) based authentication backend.
This backend also implements authorization workflow with some defaults. This means that you can provide your own unauthorized-handler hook if the default one does not satisfy you.
Create an instance of the jws (signed JWT) based authentication backend. This backend also implements authorization workflow with some defaults. This means that you can provide your own unauthorized-handler hook if the default one does not satisfy you.
(session)(session opts)Create an instance of the http session based authentication backend.
This backend also implements authorization workflow with some defaults. This means that you can provide your own unauthorized-handler hook if the default one does not satisfy you.
Create an instance of the http session based authentication backend. This backend also implements authorization workflow with some defaults. This means that you can provide your own unauthorized-handler hook if the default one does not satisfy you.
(token)(token opts)Create an instance of the generic token based authentication backend.
This backend also implements authorization workflow with some defaults. This means that you can provide your own unauthorized-handler hook if the default one does not satisfy you.
Create an instance of the generic token based authentication backend. This backend also implements authorization workflow with some defaults. This means that you can provide your own unauthorized-handler hook if the default one does not satisfy you.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |