API-key authentication and authorization backend.
API-key authentication and authorization backend.
(api-key-backend &
[{:keys [authfn unauthorized-handler location header-name
cookie-name query-param]
:or {location :header
header-name "X-API-Key"
cookie-name "api-key"
query-param "api-key"}}])(parse-key request location header-name cookie-name query-param)Extract an API key from a Ring request according to its location.
Extract an API key from a Ring request according to its location.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |