buddy.auth.backends.jwks

The JWKS authentication and authorization backend.

The JWKS authentication and authorization backend.
raw docstring

discover-jwks-urlclj

(discover-jwks-url issuer)
(discover-jwks-url issuer fetch-json)

Fetch the OIDC discovery document and return its jwks_uri.

The two-argument form accepts a fetch function for callers that provide their own HTTP transport or for isolated testing.

Fetch the OIDC discovery document and return its `jwks_uri`.

The two-argument form accepts a fetch function for callers that provide
their own HTTP transport or for isolated testing.
sourceraw docstring

jwks-backendclj

(jwks-backend {:keys [authfn unauthorized-handler options token-name on-error
                      bearer-challenge]
               :as opts
               :or {authfn identity options {} token-name "Bearer"}})

Create a JWKS authentication backend.

:options must contain :algs or :alg to declare the expected JWT algorithm. For example, pass :options {:algs #{:rs256}}.

Create a JWKS authentication backend.

:options must contain :algs or :alg to declare the expected JWT algorithm.
For example, pass :options {:algs #{:rs256}}.
sourceraw docstring

oidc-backendclj

(oidc-backend {:keys [issuer audience nonce discovery-fn options]
               :as opts
               :or {options {}}})

Create a JWKS backend from an OIDC issuer.

Discovery is performed when no :source or :jwks-url is supplied. The expected audience is configured with :audience (or :options {:aud ...}), and an expected nonce with :nonce.

Create a JWKS backend from an OIDC issuer.

Discovery is performed when no `:source` or `:jwks-url` is supplied. The
expected audience is configured with `:audience` (or `:options {:aud ...}`),
and an expected nonce with `:nonce`.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries