Shared handling for failures raised while verifying credentials.
Shared handling for failures raised while verifying credentials.
(verify request on-error verifier)Run verifier, reporting verification exceptions through on-error.
The verifier is deliberately passed as a thunk so the authentication function is evaluated after this failure boundary and its exceptions remain visible to callers.
Run `verifier`, reporting verification exceptions through `on-error`. The verifier is deliberately passed as a thunk so the authentication function is evaluated after this failure boundary and its exceptions remain visible to callers.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |