The HTTP request and response abstraction for built-in authentication and authorization backends.
The HTTP request and response abstraction for built-in authentication and authorization backends.
(find-header headers header-name)Look up a header in a headers map without case sensitivity. Return the header map entry or nil.
Look up a header in a headers map without case sensitivity. Return the header map entry or nil.
(-get-header req name)Get a value of header.
Get a value of header.
(redirect url)(redirect url status)Returns a Ring compatible response for an HTTP 302 redirect.
Returns a Ring compatible response for an HTTP 302 redirect.
(response body)(response body status)(response body status headers)Create a Ring-compatible response with multiple arities.
Create a Ring-compatible response with multiple arities.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |